pub(crate) fn spawn_gateway_cache_refresh(client: &ClientHandleArc)Expand description
Spawn a background task that keeps the gateway cache fresh between invoices.
pub(crate) fn spawn_gateway_cache_refresh(client: &ClientHandleArc)Spawn a background task that keeps the gateway cache fresh between invoices.